
/* Chrysalide - Outil d'analyse de fichiers binaires
 * plugin.c - description et intégration du présent greffon
 *
 * Copyright (C) 2015-2017 Cyrille Bagard
 *
 *  This file is part of Chrysalide.
 *
 *  Chrysalide is free software; you can redistribute it and/or modify
 *  it under the terms of the GNU General Public License as published by
 *  the Free Software Foundation; either version 3 of the License, or
 *  (at your option) any later version.
 *
 *  Chrysalide is distributed in the hope that it will be useful,
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *  GNU General Public License for more details.
 *
 *  You should have received a copy of the GNU General Public License
 *  along with Foobar.  If not, see <http://www.gnu.org/licenses/>.
 */


#include "plugin.h"


#include <i18n.h>


#include <gui/core/global.h>
#include <gtkext/easygtk.h>
#include <plugins/plugin-def.h>


#include "select.h"



DEFINE_CHRYSALIDE_ACTIVE_PLUGIN("ROP gadgets", "Find available gadgets for a ROP chain", "0.1.0",
                                PGA_PLUGIN_INIT);



/* Réagit avec le menu "Greffons -> Lister les gadgets ROP". */
static void mcb_plugins_list_rop_gadgets(GtkMenuItem *, gpointer);



/******************************************************************************
*                                                                             *
*  Paramètres  : plugin = greffon à manipuler.                                *
*                ref    = espace de référencement global.                     *
*                                                                             *
*  Description : Prend acte du chargement du greffon.                         *
*                                                                             *
*  Retour      : -                                                            *
*                                                                             *
*  Remarques   : -                                                            *
*                                                                             *
******************************************************************************/

G_MODULE_EXPORT bool chrysalide_plugin_init(GPluginModule *plugin)
{
    GObject *ref;                           /* Espace de référencements    */
    GtkContainer *menubar;                  /* Support pour éléments       */
    GtkWidget *submenuitem;                 /* Sous-élément de menu        */

    ref = G_OBJECT(get_editor_window());    /* FIXME */

    menubar = GTK_CONTAINER(g_object_get_data(ref, "menubar_plugins"));
    if (menubar == NULL) return false;

    submenuitem = qck_create_menu_item(ref, "mnu_plugins_ropgadgets", _("List ROP gadgets"),
                                       G_CALLBACK(mcb_plugins_list_rop_gadgets), NULL);
    gtk_container_add(GTK_CONTAINER(menubar), submenuitem);

    return true;

}


/******************************************************************************
*                                                                             *
*  Paramètres  : menuitem = élément de menu sélectionné.                      *
*                unused   = adresse non utilisée ici.                         *
*                                                                             *
*  Description : Réagit avec le menu "Greffons -> Lister les gadgets ROP".    *
*                                                                             *
*  Retour      : -                                                            *
*                                                                             *
*  Remarques   : -                                                            *
*                                                                             *
******************************************************************************/

static void mcb_plugins_list_rop_gadgets(GtkMenuItem *menuitem, gpointer unused)
{
    run_rop_finder_assistant(get_editor_window());

}
